@@ -1,13 +1,11 @@
-#!/usr/bin/env python
-# -*- coding: utf-8 -*-
-
 from .common import AbstractFactory
 from .deprecated_stuff import dict_factory, parse, ParserFactory, SerializerFactory
-from .exceptions import InvalidFieldError
+from .exceptions import InvalidFieldError, UnknownFieldsError
 from .factory import Factory
 from .naming import NameStyle
 from .parsers import PARSER_EXCEPTIONS
-from .schema import Schema
+from .schema import Schema, RuleForUnknown, Unknown
+from .validators import validate
 
 __all__ = [
     "parse",
@@ -20,4 +18,8 @@ __all__ = [
     "AbstractFactory",
     "PARSER_EXCEPTIONS",
     "InvalidFieldError",
+    "RuleForUnknown",
+    "UnknownFieldsError",
+    "Unknown",
+    "validate"
 ]
